==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPivotDimensionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionStrategyDescription } from "./WebPivotDimensionStrategyDescription";
/**
 * @hidden
 */
export let WebPivotDimensionStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionStrategyDescriptionMetadata.a == null) {
                WebPivotDimensionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionStrategyDescriptionMetadata.c(WebPivotDimensionStrategyDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotDimensionStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimensionStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebPivotDimensionStrategyDescriptionMetadata.b(a);
            a.ad("WebPivotDimensionStrategy", () => new WebPivotDimensionStrategyDescription());
            a.ac("WebPivotDimensionStrategy", WebPivotDimensionStrategyDescriptionMetadata.a);
        }
    }
    WebPivotDimensionStrategyDescriptionMetadata.$t = markType(WebPivotDimensionStrategyDescriptionMetadata, 'WebPivotDimensionStrategyDescriptionMetadata');
    WebPivotDimensionStrategyDescriptionMetadata.a = null;
    return WebPivotDimensionStrategyDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPivotDimensionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionStrategyDescription } from "./WebPivotDimensionStrategyDescription";
/**
 * @hidden
 */
export let WebPivotDimensionStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionStrategyDescriptionMetadata.a == null) {
                WebPivotDimensionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionStrategyDescriptionMetadata.c(WebPivotDimensionStrategyDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotDimensionStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimensionStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebPivotDimensionStrategyDescriptionMetadata.b(a);
            a.ae("WebPivotDimensionStrategy", () => new WebPivotDimensionStrategyDescription());
            a.ad("WebPivotDimensionStrategy", WebPivotDimensionStrategyDescriptionMetadata.a);
        }
    }
    WebPivotDimensionStrategyDescriptionMetadata.$t = markType(WebPivotDimensionStrategyDescriptionMetadata, 'WebPivotDimensionStrategyDescriptionMetadata');
    WebPivotDimensionStrategyDescriptionMetadata.a = null;
    return WebPivotDimensionStrategyDescriptionMetadata;
})();
